import getMethod from './getMethod';
import getPathInfo from './getPathInfo';
import getQueryString from './getQueryString';
import parseHttpVersion from './parseHttpVersion';
export default class Request {
    constructor(stdin, env) {
        this.stdin = stdin;
        this.aborted = false;
        [this.httpVersionMajor, this.httpVersionMinor] = parseHttpVersion(env);
        this.httpVersion = `${this.httpVersionMajor}.${this.httpVersionMinor}`;
        this.headers = {};
        this.rawHeaders = [];
        for (const name in env) {
            const val = env[name];
            if (val === undefined) {
                continue;
            }
            const ra = /^HTTP_(.+)$/i.exec(name);
            if (ra) {
                const lcName = ra[1].toLowerCase().replace(/_/g, '-');
                this.headers[lcName] = val;
                this.rawHeaders.push(`${lcName}: ${val}`);
            }
        }
        this.trailers = {};
        this.rawTrailers = [];
        this.method = getMethod(env);
        const path = getPathInfo(env);
        const qs = getQueryString(env);
        this.url = `${path !== undefined && path !== '' ? path : '/'}${qs !== undefined ? '?' + qs : ''}`;
    }
    get connection() {
        throw new Error('connection is not usable');
    }
    get socket() {
        return null;
    }
    get readable() {
        return this.stdin.readable && this.stdin.readableLength > 0;
    }
    get readableFlowing() {
        return this.stdin.readableFlowing;
    }
    get readableHighWaterMark() {
        return this.stdin.readableHighWaterMark;
    }
    get readableLength() {
        return this.stdin.readableLength;
    }
    get complete() {
        return this.stdin.readableLength === 0;
    }
    setTimeout(_msecs, _callback) {
        throw new Error('Method not implemented.');
    }
    destroy(error) {
        this.stdin.destroy(error);
    }
    _read(size) {
        this.stdin._read(size);
    }
    read(size) {
        return this.read(size);
    }
    setEncoding(encoding) {
        this.stdin.setEncoding(encoding);
        return this;
    }
    pause() {
        this.stdin.pause();
        return this;
    }
    resume() {
        this.stdin.resume();
        return this;
    }
    isPaused() {
        return this.stdin.isPaused();
    }
    unpipe(destination) {
        console.error('*** Unpipe here:', this.stdin);
        this.stdin.unpipe(destination);
        return this;
    }
    unshift(chunk) {
        this.stdin.unshift(chunk);
    }
    wrap(oldStream) {
        this.stdin.wrap(oldStream);
        return this;
    }
    push(chunk, encoding) {
        return this.stdin.push(chunk, encoding);
    }
    _destroy(error, callback) {
        this._destroy(error, callback);
    }
    addListener(event, listener) {
        this.stdin.addListener(event, listener);
        return this;
    }
    emit(event, ...args) {
        return this.stdin.emit(event, ...args);
    }
    on(event, listener) {
        this.stdin.on(event, listener);
        return this;
    }
    once(event, listener) {
        this.stdin.once(event, listener);
        return this;
    }
    prependListener(event, listener) {
        this.stdin.prependListener(event, listener);
        return this;
    }
    prependOnceListener(event, listener) {
        this.stdin.prependOnceListener(event, listener);
        return this;
    }
    removeListener(event, listener) {
        this.stdin.removeListener(event, listener);
        return this;
    }
    [Symbol.asyncIterator]() {
        return this.stdin[Symbol.asyncIterator]();
    }
    pipe(destination, options) {
        return this.stdin.pipe(destination, options);
    }
    off(event, listener) {
        this.stdin.off(event, listener);
        return this;
    }
    removeAllListeners(event) {
        this.stdin.removeAllListeners(event);
        return this;
    }
    setMaxListeners(n) {
        this.stdin.setMaxListeners(n);
        return this;
    }
    getMaxListeners() {
        return this.stdin.getMaxListeners();
    }
    listeners(event) {
        return this.stdin.listeners(event);
    }
    rawListeners(event) {
        return this.stdin.rawListeners(event);
    }
    listenerCount(type) {
        return this.stdin.listenerCount(type);
    }
    eventNames() {
        return this.stdin.eventNames();
    }
}
